@@ -6,6 +6,7 @@ G_DEFINE_TYPE (CcMediaFactory, cc_media_factory, G_TYPE_OBJECT)
 static const gchar * cc_gst_elements[ELEMENT_NONE + 1] = {
   [ELEMENT_VP8] = "vp8enc",
   [ELEMENT_X264] = "x264enc",
+  [ELEMENT_VAH264] = "vah264enc",
   [ELEMENT_VAAPIH264] = "vaapih264enc",
   [ELEMENT_VIDEO_NONE] = NULL,
 
@@ -48,7 +49,7 @@ cc_media_factory_create_video_element (CcMediaFactory *self)
   g_autoptr(GstElement) source = NULL;
 
   GstElement *scale;
-  GstElement *sizefilter;
+  GstElement *sinkfilter;
   GstElement *convert;
   GstElement *queue_pre_encoder;
   GstElement *encoder;
@@ -82,9 +83,9 @@ cc_media_factory_create_video_element (CcMediaFactory *self)
                               "width", G_TYPE_INT, 1920,
                               "height", G_TYPE_INT, 1080,
                               NULL);
-  sizefilter = gst_element_factory_make ("capsfilter", "cc-sizefilter");
-  success &= gst_bin_add (bin, sizefilter);
-  g_object_set (sizefilter,
+  sinkfilter = gst_element_factory_make ("capsfilter", "cc-sinkfilter");
+  success &= gst_bin_add (bin, sinkfilter);
+  g_object_set (sinkfilter,
                 "caps", caps,
                 NULL);
   g_clear_pointer (&caps, gst_caps_unref);
@@ -112,6 +113,16 @@ cc_media_factory_create_video_element (CcMediaFactory *self)
       caps = gst_caps_from_string ("video/x-h264,stream-format=avc,alignment=au,profile=high");
       break;
 
+    case ELEMENT_VAH264:
+      encoder = gst_element_factory_make ("vah264enc", "cc-video-encoder");
+      g_object_set (encoder,
+                    "rate-control", 2,
+                    NULL);
+
+      parser = gst_element_factory_make ("h264parse", "cc-h264parse");
+      caps = gst_caps_from_string ("video/x-h264,stream-format=avc,alignment=au,profile=high");
+      break;
+
     case ELEMENT_VAAPIH264:
       encoder = gst_element_factory_make ("vaapih264enc", "cc-video-encoder");
       g_object_set (encoder,
@@ -171,7 +182,7 @@ cc_media_factory_create_video_element (CcMediaFactory *self)
 
   success &= gst_element_link_many (source,
                                     scale,
-                                    sizefilter,
+                                    sinkfilter,
                                     convert,
                                     queue_pre_encoder,
                                     encoder,
