@@ -259,6 +259,9 @@ nd_cc_sink_sink_stop_stream (NdSink *sink)
 {
   NdCCSink *self = ND_CC_SINK (sink);
 
+  if (self->state == ND_SINK_STATE_DISCONNECTED)
+    return;
+
   nd_cc_sink_sink_stop_stream_int (self);
 
   self->state = ND_SINK_STATE_DISCONNECTED;
@@ -338,16 +341,16 @@ static gchar *
 nd_cc_sink_sink_to_uri (NdSink *sink)
 {
   NdCCSink *self = ND_CC_SINK (sink);
-  GHashTable *params = g_hash_table_new (g_str_hash, g_str_equal);
+  g_autoptr(GHashTable) params = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_free);
 
   /* protocol */
-  g_hash_table_insert (params, "protocol", (gpointer *) g_strdup_printf ("%d", protocol));
+  g_hash_table_insert (params, "protocol", g_strdup_printf ("%d", protocol));
 
   /* remote name */
-  g_hash_table_insert (params, "name", (gpointer *) g_strdup (self->name));
+  g_hash_table_insert (params, "name", g_strdup (self->name));
 
   /* remote address */
-  g_hash_table_insert (params, "ip", (gpointer *) g_strdup (self->ip));
+  g_hash_table_insert (params, "ip", g_strdup (self->ip));
 
   return nd_uri_helpers_generate_uri (params);
 }
