@@ -19,7 +19,10 @@
 #pragma once
 
 #include <glib-object.h>
+#include <nd-sink.h>
 
 gchar * nd_uri_helpers_generate_uri (GHashTable *params);
 
 GHashTable * nd_uri_helpers_parse_uri (gchar *uri);
+
+NdSink * nd_uri_helpers_uri_to_sink (gchar *uri);
